@@ -1,13 +1,7 @@
-#define BOOST_TEST_MODULE "test_comments"
-#ifdef UNITTEST_FRAMEWORK_LIBRARY_EXIST
-#include <boost/test/unit_test.hpp>
-#else
-#define BOOST_TEST_NO_LIB
-#include <boost/test/included/unit_test.hpp>
-#endif
-
 #include <toml.hpp>
 
+#include "unit_test.hpp"
+
 BOOST_AUTO_TEST_CASE(test_comment_before)
 {
     {
