@@ -1,22 +1,17 @@
-#define BOOST_TEST_MODULE "test_find"
-
-#ifdef UNITTEST_FRAMEWORK_LIBRARY_EXIST
-#include <boost/test/unit_test.hpp>
-#else
-#define BOOST_TEST_NO_LIB
-#include <boost/test/included/unit_test.hpp>
-#endif
-
 #include <toml.hpp>
-#include <map>
-#include <unordered_map>
-#include <list>
-#include <deque>
+
+#include "unit_test.hpp"
+
 #include <array>
+#include <deque>
+#include <list>
+#include <map>
+#include <tuple>
+#include <unordered_map>
+
 #if TOML11_CPLUSPLUS_STANDARD_VERSION >= 201703L
 #include <string_view>
 #endif
-#include <tuple>
 
 using test_value_types = std::tuple<
     toml::basic_value<toml::discard_comments>,
@@ -830,4 +825,3 @@ BOOST_AUTO_TEST_CASE_TEMPLATE(test_get_toml_offset_datetime, value_type, test_va
         BOOST_TEST(tm.tm_sec ==            0);
     }
 }
-
