@@ -1,13 +1,9 @@
-#define BOOST_TEST_MODULE "test_acceptor"
-#ifdef UNITTEST_FRAMEWORK_LIBRARY_EXIST
-#include <boost/test/unit_test.hpp>
-#else
-#define BOOST_TEST_NO_LIB
-#include <boost/test/included/unit_test.hpp>
-#endif
 #include <toml/utility.hpp>
-#include <vector>
+
+#include "unit_test.hpp"
+
 #include <array>
+#include <vector>
 
 BOOST_AUTO_TEST_CASE(test_try_reserve)
 {
